/**
 * File customizer.js.
 *
 * Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Theme Customizer preview reload changes asynchronously.
 */

( function( $ ) {

	// Site title and description.
	wp.customize( 'blogname', function( value ) {
		value.bind( function( to ) {
			$( '.site-title a' ).text( to );
		} );
	} );
	wp.customize( 'blogdescription', function( value ) {
		value.bind( function( to ) {
			$( '.site-description' ).text( to );
		} );
	} );

	// Color scheme
	wp.customize( 'emerge_color_scheme', function( value ) {
		value.bind( function( to ) {
			if ( 'lite' === to ) {
				$( 'body' ).addClass( 'lite-version' );
				$( 'body' ).removeClass( 'dark-version' );
			} else {
				$( 'body' ).addClass( 'dark-version' );
				$( 'body' ).removeClass( 'lite-version' );
			}
		} );
	} );

	// Global site layout
	wp.customize( 'emerge_site_layout', function( value ) {
		value.bind( function( to ) {
			if ( 'box' === to ) {
				$( 'body' ).addClass( 'boxed' );
			} else {
				$( 'body' ).removeClass( 'boxed' );
			}
		} );
	} );

	// Header title color.
	wp.customize( 'emerge_header_title_color', function( value ) {
		value.bind( function( to ) {
			if ( 'blank' === to ) {
				$( '.site-title' ).css( {
					'clip': 'rect(1px, 1px, 1px, 1px)',
					'position': 'absolute'
				} );
			} else {
				$( '.site-title a' ).css( {
					'color': to
				} );
			}
		} );
	} );

	// Header tagline color.
	wp.customize( 'emerge_header_tagline', function( value ) {
		value.bind( function( to ) {
			if ( 'blank' === to ) {
				$( '.site-description' ).css( {
					'clip': 'rect(1px, 1px, 1px, 1px)',
					'position': 'absolute'
				} );
			} else {
				$( '.site-description' ).css( {
					'color': to
				} );
			}
		} );
	} );

	// Header text display.
	wp.customize( 'emerge_header_text_display', function( value ) {
		value.bind( function( to ) {
			if ( to ) {
				$( '.site-branding-text' ).css( {
					'display': 'block',
				} );
			} else {
				$( '.site-branding-text' ).css( {
					'display': 'none',
				} );
			}
		} );
	} );
} )( jQuery );
