<?php
/**
 * Template part for displaying front page about.
 *
 * @package Moral
 */
// Get default  mods value.
$default = emerge_get_default_mods();

// Get the content type.
$about = get_theme_mod( 'emerge_about', 'custom' );

// Bail if the section is disabled.
if ( 'disable' === $about ) {
	return;
}

// Query if the content type is either post or page.
if (  in_array( $about, array( 'post', 'page' ) ) ) {

	if ( 'post' === $about ) {
		$id = get_theme_mod( 'emerge_about_post' );
	} else {
		$id = get_theme_mod( 'emerge_about_page' );
	}

	$query = new WP_Query( array( 'post_type' => $about, 'p' => absint( $id ) ) );

	if ( $query->have_posts() ) {
		while ( $query->have_posts() ) {
			$query->the_post();
			if ( has_post_thumbnail() ) {
				$img     = get_the_post_thumbnail( $id, 'full', array( 'alt' => the_title_attribute( 'echo=0' ) ) );
			}
			$title   = get_the_title();
			$content = get_the_excerpt();
			$btn_url     = get_permalink();
		}
		wp_reset_postdata();
	}
} else {
	$title   = get_theme_mod( 'emerge_about_title', $default['emerge_about_title'] );
	$content = get_theme_mod( 'emerge_about_content', $default['emerge_about_content'] );
	$btn_url     = get_theme_mod( 'emerge_about_link' );

	$img_url = get_theme_mod( 'emerge_about_image' );
	if ( $img_url ) {
		$img     = '<img src="' . esc_url( $img_url ) . '" alt="' . esc_attr( $title ) . '">';
	}
}

// Get the common settings value  in custom, page and post.
$sub_title   = get_theme_mod( 'emerge_about_sub_title', $default['emerge_about_sub_title'] );
$btn_txt = get_theme_mod( 'emerge_about_btn_txt', $default['emerge_about_btn_txt'] );
?>

<div id="about-us" class="relative page-section">
    <div class="wrapper">
        <div class="section-header">
            <h2 class="section-title"><?php echo esc_html( $title ); ?></h2>
            <h5 class="section-subtitle"><?php echo esc_html( $sub_title ); ?></h5>
        </div><!-- .section-header -->

        <?php $class = ( isset( $img ) ) ? 'has-featured-image' : 'no-featured-image' ; ?>
        <article class="<?php echo esc_attr( $class ); ?>">
        	<?php if ( isset( $img ) ) : ?>
	            <div class="featured-image">  
	                <?php echo $img; ?>
	            </div><!-- .featured-image -->
        	<?php endif; ?>

            <div class="entry-container">
                <div class="section-header">
                    <h2 class="section-title"><?php echo esc_html( $title ); ?></h2>
                    <h5 class="section-subtitle"><?php echo esc_html( $sub_title ); ?></h5>
                </div><!-- .section-header -->

                <div class="entry-content">
                	<?php echo wp_kses_post( $content ); ?>
                </div><!-- .entry-content -->

                <?php if ( ! empty( $btn_txt ) ) : ?>
	                <div class="read-more">
	                    <a href="<?php echo esc_url( $btn_url ); ?>" class="btn btn-primary"><?php echo esc_html( $btn_txt ); ?></a>
	                </div><!-- .read-more -->
                <?php endif; ?>
            </div><!-- .entry-container -->
        </article>
    </div><!-- .wrapper -->
</div><!-- #about-us -->