<?php
/**
 * Template part for displaying front page portfolio.
 *
 * @package Moral
 */

// Get default  mods value.
$portfolio = get_theme_mod( 'emerge_portfolio', 'custom' );

if ( 'disable' === $portfolio ) {
	return;
}

$default = emerge_get_default_mods();
$section_title = get_theme_mod( 'emerge_portfolio_title', $default['emerge_portfolio_title'] );
$section_sub_title = get_theme_mod( 'emerge_portfolio_sub_title', $default['emerge_portfolio_sub_title'] );

?>
<div id="latest-portfolios" class="relative page-section">
    <div class="wrapper">
        <div class="section-header">
            <h2 class="section-title"><?php echo esc_html( $section_title ); ?></h2>
            <h5 class="section-subtitle"><?php echo esc_html( $section_sub_title ); ?></h5>
        </div><!-- .section-header -->

        <div class="section-content">
            <div class="grid">
				<?php
				$portfolio_num = get_theme_mod( 'emerge_portfolio_num', 6 );

				if (  in_array( $portfolio, array( 'post', 'page', 'cat' ) ) ) {

					if ( 'cat' === $portfolio ) {
						$cat_id = get_theme_mod( 'emerge_portfolio_cat' );
						$args = array(
							'cat' => $cat_id,	
							'posts_per_page' => $portfolio_num,
						);
					} else {
						$id_arr = array();
						for ( $i=1; $i <= $portfolio_num; $i++ ) { 
							$id = get_theme_mod( "emerge_portfolio_{$portfolio}_" . $i );
							if ( $id ) {
								$id_arr[] = $id;
							}
						}
						$args = array(
							'post_type' => $portfolio,
							'post__in' => (array)$id_arr,	
							'posts_per_page' => $portfolio_num,
                            'orderby'   => 'post__in',
							'ignore_sticky_posts' => true,
						);
					}

					$query = new WP_Query( $args );

					if ( $query->have_posts() ) {
						while ( $query->have_posts() ) {
							$query->the_post();
							?>
							<div class="grid-item">
				                <div class="grid-inner-wrapper">
				                    <div class="overlay"></div>
				                    <a href="<?php the_permalink(); ?>"><?php the_post_thumbnail( 'full', array( 'alt' => the_title_attribute( 'echo=0' ) ) ); ?></a>
				                    <div class="hover-item">
				                        <h5><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h5>
				                        <p><?php echo wp_trim_words( get_the_excerpt(), 15 ); ?></p>
				                    </div><!-- .hover-item -->
				                </div><!-- .grid-inner-wrapper -->
				            </div><!-- .grid-item -->
						<?php	
						}
						wp_reset_postdata();
					}
				} else {
					for ( $i=1; $i <= $portfolio_num; $i++ ) { 
						$title   = get_theme_mod( 'emerge_portfolio_custom_title_' . $i, $default['emerge_portfolio_custom_title'] );
						$excerpt   = get_theme_mod( 'emerge_portfolio_custom_content_' . $i, $default['emerge_portfolio_custom_content'] );
						$url   = get_theme_mod( 'emerge_portfolio_link_' . $i, '#' );
						$img   = '<img src="' . esc_url( get_theme_mod( 'emerge_portfolio_image_' . $i, $default['emerge_portfolio_image'] ) ) . '" alt="' . esc_attr( $title ) . '">';
						?>
						<div class="grid-item">
					        <div class="grid-inner-wrapper">
					            <div class="overlay"></div>
					            <a href="<?php echo esc_url( $url ); ?>"><?php echo $img; ?></a>
					            <div class="hover-item">
					                <h5><a href="<?php echo esc_url( $url ); ?>"><?php echo esc_html( $title ); ?></a></h5>
					                <p><?php echo esc_html( $excerpt ); ?></p>
					            </div><!-- .hover-item -->
					        </div><!-- .grid-inner-wrapper -->
					    </div><!-- .grid-item -->
						<?php	
					}
				}
				?>
            </div><!-- .grid -->
        </div><!-- .section-content -->

        <?php 
        $btn_txt = get_theme_mod( 'emerge_portfolio_btn_txt', esc_html( 'Show More', 'emerge-pro' ) );
        if ( 'cat' === $portfolio) {
        	$btn_link = get_category_link( $cat_id );
        } else {
        	$btn_link = get_theme_mod( 'emerge_portfolio_link', '#' );
        }
        if ( ! empty( $btn_txt ) ) { ?>
	        <div class="load-more align-center">
	            <a href="<?php echo esc_url( $btn_link ); ?>" class="btn btn-default"><?php echo esc_html( $btn_txt ); ?></a>
	        </div><!-- .read-more -->
        <?php } ?>
    </div><!-- .wrapper -->
</div><!-- #latest-portfolios -->