<?php
/**
 * Template part for displaying front page reasons.
 *
 * @package Moral
 */

// Get default  mods value.
$reasons_enable = get_theme_mod( 'emerge_reasons_enable', true );

if ( ! $reasons_enable ) {
    return;
}

$default = emerge_get_default_mods();
$section_title = get_theme_mod( 'emerge_reasons_title', $default['emerge_reasons_title'] );
$section_sub_title = get_theme_mod( 'emerge_reasons_sub_title', $default['emerge_reasons_sub_title'] );

$reasons_left_enable = get_theme_mod( 'emerge_reasons_content', 'custom' );
$skill_enable = get_theme_mod( 'emerge_reasons_skill_enable', true );


$skill_class = ( $skill_enable ) ? 'has-skills-bar' : '' ;
$skill_class = ( 'disable' === $reasons_left_enable ) ? '' : $skill_class ;

?>

<div id="reasons" class="relative page-section <?php echo esc_attr( $skill_class );?>">
    <div class="wrapper">
        <div class="reasons-wrapper">
            <div class="section-header">
                <h2 class="section-title"><?php echo esc_html( $section_title ); ?></h2>
                <h5 class="section-subtitle"><?php echo esc_html( $section_sub_title ); ?></h5>
            </div><!-- .section-header -->


            <?php
            if( 'disable' != $reasons_left_enable ) :
                $reasons_left_content  = get_theme_mod( 'emerge_reasons_content', 'custom' );
                // Query if the content type is either post or page.
                if (  in_array( $reasons_left_content, array( 'post', 'page' ) ) ) {

                    if ( 'post' === $reasons_left_content ) {
                        $id = get_theme_mod( 'emerge_reasons_post' );
                    } else {
                        $id = get_theme_mod( 'emerge_reasons_page' );
                    }

                    $query = new WP_Query( array( 'posts_per_page' => 1, 'post_type' => $reasons_left_content, 'p' => absint( $id ) ) );

                    if ( $query->have_posts() ) {
                        while ( $query->have_posts() ) {
                            $query->the_post();
                            $btn_link = get_permalink();
                        ?>
                        <div class="entry-content">
                            <?php the_excerpt(); ?>
                        </div><!-- .entry-content -->
                        <?php
                        }
                        wp_reset_postdata();
                    }
                } else {
                    $content = get_theme_mod( 'emerge_reasons_custom_content', $default['emerge_reasons_custom_content'] );
                    $btn_link = get_theme_mod( 'emerge_reasons_link', '#' );
                    ?>
                    <div class="entry-content">
                        <p><?php echo esc_html( $content ); ?></p>
                    </div><!-- .entry-content -->

                <?php
                }
                $btn_text = get_theme_mod( 'emerge_reasons_custom_btn_txt', esc_html__( 'Read More', 'emerge-pro' ) );
                if ( ! empty( $btn_text ) ) :
                ?>
                    <div class="read-more">
                        <a href="<?php echo esc_url( $btn_link );?>" class="btn btn-primary"><?php echo esc_html( $btn_text ); ?></a>
                    </div><!-- .read-more -->
                <?php
                endif;
            endif;

            if ( 'disable' != $reasons_left_enable || ( $skill_enable && 'disable' != $reasons_left_enable ) ) {
                echo "</div><!-- .reasons-wrapper -->";
            }
            
        if ( $skill_enable ) : ?>
            <div class="skills-wrapper">
                <div class="skill-item">
                    <?php  
                    $skill_num = get_theme_mod( 'emerge_reasons_skill_num', 4 );
                    for ( $i=1; $i <= $skill_num; $i++ ) { 
                        $skill_title = get_theme_mod( 'emerge_reasons_skill_title_' . $i, esc_html( 'Management', 'emerge-pro' ) );
                        $skill_value = get_theme_mod( 'emerge_reasons_skill_value_' . $i, 40 );
                        $skill_color = get_theme_mod( 'emerge_reasons_skill_color_' . $i, '' );
                        ?>
                        <div class="skill-outerbox">
                            <div style="background-color:<?php echo esc_attr( $skill_color );?>;"  class="skill-innerbox" skill-value="<?php echo esc_attr( $skill_value ); ?>%">
                                <span class="skill-title"><?php echo esc_html( $skill_title ); ?></span>
                                <span class="skill-value"><?php echo absint( $skill_value ); ?>%</span>
                            </div>
                        </div><!-- .skill-outerbox -->
                    <?php } ?>
                </div><!-- .skill-item -->
            </div><!-- .skills-wrapper -->
        <?php endif; 
        if ( $skill_enable && 'disable' === $reasons_left_enable ) {
            echo "</div><!-- .reasons-wrapper -->";
        }
        ?>
    </div><!-- .wrapper -->
</div><!-- #reasons -->