<?php
/**
 * Template part for displaying front page services.
 *
 * @package Moral
 */

// Get default  mods value.
$services = get_theme_mod( 'emerge_services', 'custom' );

if ( 'disable' === $services ) {
    return;
}

$default = emerge_get_default_mods();
$section_title = get_theme_mod( 'emerge_services_title', $default['emerge_services_title'] );
$section_sub_title = get_theme_mod( 'emerge_services_sub_title', $default['emerge_services_sub_title'] );

$services_num = get_theme_mod( 'emerge_services_num', 6 );

$col_class = ( $services_num % 3 === 0  ) ? 3 : 4 ;

?>
<!-- .supports column 3 and 4 -->
<div id="our-services" class="relative page-section col-<?php echo absint( $col_class );?>">
    <div class="wrapper">
        <div class="section-header">
            <h2 class="section-title"><?php echo esc_html( $section_title ); ?></h2>
            <h5 class="section-subtitle"><?php echo esc_html( $section_sub_title ); ?></h5>
        </div><!-- .section-header -->

        <div class="entry-container">
                <?php

                if (  in_array( $services, array( 'post', 'page', 'cat' ) ) ) {

                    if ( 'cat' === $services ) {
                        $cat_id = get_theme_mod( 'emerge_services_cat' );
                        $args = array(
                            'cat' => $cat_id,   
                            'posts_per_page' => $services_num,
                        );
                    } else {
                        $id = array();
                        for ( $i=1; $i <= $services_num; $i++ ) { 
                            $id[] = get_theme_mod( "emerge_services_{$services}_" . $i );
                        }
                        $args = array(
                            'post_type' => $services,
                            'post__in' => (array)$id,   
                            'orderby'   => 'post__in',
                            'posts_per_page' => $services_num,
                            'ignore_sticky_posts' => true,
                        );
                    }

                    $query = new WP_Query( $args );

                    if ( $query->have_posts() ) :
                        while ( $query->have_posts() ) :
                            $query->the_post();
                            ?>
                        
                            <article>
                                <?php if ( has_post_thumbnail() ) : ?>
                                    <div class="service-icon">
                                        <a href="<?php the_permalink(); ?>"><?php the_post_thumbnail( 'full', array( 'alt' => the_title_attribute( 'echo=0' ) ) ); ?></a>
                                    </div><!-- .service-icon -->
                                <?php endif; ?>

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>
                                </header>   

                                <div class="entry-content"><?php echo wp_trim_words( get_the_excerpt(), 15 ); ?></div><!-- .entry-content -->
                            </article>
                        <?php endwhile;
                        wp_reset_postdata();
                    endif; 
                } else {
                    for ( $i=1; $i <= $services_num; $i++ ) { 
                        $title   = get_theme_mod( 'emerge_services_custom_title_' . $i, $default['emerge_services_custom_title'] );
                        $excerpt   = get_theme_mod( 'emerge_services_custom_content_' . $i, $default['emerge_services_custom_content'] );
                        $url   = get_theme_mod( 'emerge_services_link_' . $i, '#' );
                        $img   = '<img src="' . esc_url( get_theme_mod( 'emerge_services_image_' . $i, $default['emerge_services_image'] ) ) . '" alt="' . esc_attr( $title ) . '">';
                        ?>
                        <article>
                            <div class="service-icon">
                                <a href="<?php echo esc_url( $url ); ?>"><?php echo $img; ?></a>
                            </div><!-- .service-icon -->

                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $url ); ?>"><?php echo esc_html( $title ); ?></a></h2>
                            </header>   

                            <div class="entry-content"><?php echo esc_html( $excerpt ); ?></div><!-- .entry-content -->
                        </article>
                <?php   
                    }
                }
                ?>
        </div><!-- .entry-container -->
    </div><!-- .wrapper -->
</div><!-- #our-services -->