<?php
/**
 * Template part for displaying front page testimonial.
 *
 * @package Moral
 */

// Get default  mods value.
$testimonial = get_theme_mod( 'emerge_testimonial', 'custom' );

if ( 'disable' === $testimonial ) {
    return;
}

$default = emerge_get_default_mods();
$section_title = get_theme_mod( 'emerge_testimonial_title', $default['emerge_testimonial_title'] );
$section_sub_title = get_theme_mod( 'emerge_testimonial_sub_title', $default['emerge_testimonial_sub_title'] );

$testimonial_num = get_theme_mod( 'emerge_testimonial_num', 3 );

?>
<div id="testimonial" class="relative page-section">
	<div class="wrapper">
		<div class="section-header">
            <h2 class="section-title"><?php echo esc_html( $section_title ); ?></h2>
            <h5 class="section-subtitle"><?php echo esc_html( $section_sub_title ); ?></h5>
        </div><!-- .section-header -->

        <div class="section-content">
	        <div class="testimonial-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 800, "dots": true, "arrows":false, "autoplay": true, "fade": false }'>
	        	<?php

	        	if (  in_array( $testimonial, array( 'post', 'page', 'cat' ) ) ) {

	        	    if ( 'cat' === $testimonial ) {
	        	        $cat_id = get_theme_mod( 'emerge_testimonial_cat' );
	        	        $args = array(
	        	            'cat' => $cat_id,   
	        	            'posts_per_page' => $testimonial_num,
	        	        );
	        	    } else {
	        	        $id = array();
	        	        for ( $i=1; $i <= $testimonial_num; $i++ ) { 
	        	            $id[] = get_theme_mod( "emerge_testimonial_{$testimonial}_" . $i );
	        	        }
	        	        $args = array(
	        	            'post_type' => $testimonial,
	        	            'post__in' => (array)$id,   
                            'orderby'   => 'post__in',
	        	            'posts_per_page' => $testimonial_num,
	        	            'ignore_sticky_posts' => true,
	        	        );
	        	    }

	        	    $query = new WP_Query( $args );

	        	    if ( $query->have_posts() ) :
	        	        while ( $query->have_posts() ) :
	        	            $query->the_post();
	        	            ?>
	        	        
	        	            <article class="slick-item">
	        	            	<?php if ( has_post_thumbnail() ) { ?>
		        	                <div class="featured-image">
		        	                    <?php  the_post_thumbnail( 'full', array( 'alt' => the_title_attribute( 'echo=0' ) ) ); ?>
		        	                </div><!-- .featured-image -->
	        	            	<?php } ?>

	        	                <div class="entry-content">
	        	                    <?php the_content(); ?>
	        	                    <span class="position"><?php the_title(); ?></span>
	        	                </div><!-- .entry-content -->
	        	            </article>
	        	        <?php endwhile;
	        	        wp_reset_postdata();
	        	    endif; 
	        	} else {
	        	    for ( $i=1; $i <= $testimonial_num; $i++ ) { 
	        	        $title   = get_theme_mod( 'emerge_testimonial_custom_name_' . $i, $default['emerge_testimonial_custom_name'] );
	        	        $excerpt   = get_theme_mod( 'emerge_testimonial_custom_content_' . $i, $default['emerge_testimonial_custom_content'] );

	        	        $img_url = get_theme_mod( 'emerge_testimonial_image_' . $i );
	        	        $img = '';
	        	        if ( ! empty( $img_url ) ) {
	        	        	$img   = '<img src="' . esc_url( $img_url ) . '" alt="' . esc_attr( $title ) . '">';
	        	        }
	        	        ?>
	        	        <article class="slick-item">
	        	        	<?php if ( ! empty( $img ) ) { ?>
		        	            <div class="featured-image">
		        	                <?php echo $img; ?>
		        	            </div><!-- .featured-image -->
	        	        	<?php } ?>

	        	            <div class="entry-content">
	        	                <p><?php echo wp_kses_post( $excerpt ); ?></p>
	        	                <span class="position"><?php echo esc_html( $title ); ?></span>
	        	            </div><!-- .entry-content -->
	        	        </article>
	        	<?php   
	        	    }
	        	}
	        	?>
	        </div><!-- .testimonial-slider -->
        </div><!-- .section-content -->
	</div><!-- .wrapper -->
</div><!-- #our-team -->