<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Moral
 */
?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="http://gmpg.org/xfn/11">

	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<div id="page" class="site">
	<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'emerge-pro' ); ?></a>

    <header id="masthead" class="site-header" role="banner">
        <div class="wrapper">
            <div class="site-branding">
                <?php if ( has_custom_logo() ) : ?>
                    <div class="site-logo">
    					<?php the_custom_logo(); ?>
                    </div><!-- .site-logo -->
                <?php endif; ?>

                <div class="site-branding-text">
                    <?php
					if ( is_front_page() ) : ?>
						<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
					<?php else : ?>
						<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
					<?php
					endif;

					$description = get_bloginfo( 'description', 'display' );
					if ( $description || is_customize_preview() ) : ?>
						<p class="site-description"><?php echo $description; /* WPCS: xss ok. */ ?></p>
					<?php
					endif; ?>
                </div><!-- .site-branding-text -->
            </div><!-- .site-branding -->

            <div id="site-header-menu" class="site-header-menu">
                <?php if ( has_nav_menu( 'primary' ) ) : ?>
                    <button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
                        <span class="icon"></span>
                        <span class="menu-label"><?php echo esc_html__( 'Menu', 'emerge-pro' );?></span>
                    </button>
                    <?php
					wp_nav_menu( array(
						'theme_location' => 'primary',
						'menu_id'        => 'primary-menu',
						'menu_class'	 => 'menu nav-menu',
						'container'		 => 'nav',
						'container_class' => 'main-navigation',
						'container_id' => 'site-navigation',
                    ) );
                elseif( current_user_can( 'edit_theme_options' ) ): ?>
                    <nav class="main-navigation" id="site-navigation">
                        <ul id="primary-menu" class="menu nav-menu">
                            <li><a href="<?php echo esc_url( admin_url( 'nav-menus.php' ) ); ?>"><?php echo esc_html__( 'Add a menu', 'emerge-pro' );?></a></li>
                        </ul>
                    </nav>
                <?php endif; ?> 
            </div><!-- #site-header-menu -->
        </div><!-- .wrapper -->
    </header><!-- #masthead -->

	<div id="content" class="site-content">
        <?php
        $hero_content_enable_entire = get_theme_mod( 'emerge_hero_content_enable_on_entire', false );
        if ( $hero_content_enable_entire || ( ! $hero_content_enable_entire && emerge_is_frontpage() ) ) {
            get_template_part( 'frontpage-parts/hero', 'content' ); 
        }
        ?>

        <?php  
        $breadcrumb_enable = get_theme_mod( 'emerge_breadcrumb_enable', true );
        if ( ! ( emerge_is_frontpage() || emerge_is_latest_posts() ) && $breadcrumb_enable ) : 
            $breadcrumb_home = get_theme_mod( 'emerge_breadcrumb_home', false );
            ?>
            <div id="breadcrumb-list">
                <div class="wrapper">
                    <?php echo emerge_breadcrumb( array( 'show_on_front'   => false, 'show_browse' => false ) ); ?>
                </div><!-- .wrapper -->
            </div><!-- #breadcrumb-list -->
        <?php endif; ?>
