<?php
class Emerge_Pricing_Table extends WP_Widget {

	/**
	 * Sets up the widgets name etc
	 */
	public function __construct() {
		$widget_ops = array( 
			'classname' => 'emerge-pricing',
			'description' => 'Add pricing tables.',
		);
		parent::__construct( 'emerge-pricing', esc_html__( 'Moral Pricing Table', 'emerge-pro' ), $widget_ops );
	}

	/**
	 * Outputs the content of the widget
	 *
	 * @param array $args
	 * @param array $instance
	 */
	public function widget( $args, $instance ) {
		// outputs the content of the widget
		$title = isset( $instance['title'] ) ? $instance['title'] : esc_html__( 'Premium', 'emerge-pro' );
		/** This filter is documented in wp-includes/widgets/class-wp-widget-pages.php */
		$title = apply_filters( 'widget_title', $title, $instance, $this->id_base );
		
		$price = isset( $instance['price'] ) ? $instance['price'] : __( '$89', 'emerge-pro' );

		$per = isset( $instance['per'] ) ? $instance['per'] : __( 'Month', 'emerge-pro' );

		$features_num = isset( $instance['features_num'] ) ? $instance['features_num'] : 6;

		$btn_txt = isset( $instance['btn_txt'] ) ? $instance['btn_txt'] : esc_html__( 'Start', 'emerge-pro' );

		$btn_url = isset( $instance['btn_url'] ) ? $instance['btn_url'] : '#';

		$make_featured = isset( $instance['make_featured'] ) ? (bool)$instance['make_featured'] : false;
		$class = '';
		if ( $make_featured ) {
			$class = 'featured';
		}
		?>
			<article class="<?php echo esc_attr( $class ); ?>">
				<?php if ( ! empty( $title ) ) : ?>
					<header class="entry-header">
						<h2 class="entry-title"><?php echo esc_html( $title ); ?></h2>
					</header>
				<?php endif; ?>

					<div class="product-price">
						<h3><?php echo esc_html( $price ); ?></h3>
						<span><?php echo esc_html( $per ); ?></span>
					</div><!-- .product-price -->

				<div class="entry-content">
					<ul>
						<?php  
						for ( $i=1; $i <= $features_num; $i++ ) { 
							$features_txt = isset( $instance['features_txt_' . $i] ) ? $instance['features_txt_' . $i ] : __( 'Access To <a href="#">Themes</a>', 'emerge-pro' );
							if ( ! empty( $features_txt ) ) {
							?>
								<li><?php echo wp_kses_post( $features_txt ); ?></li>
							<?php 
							}
						} 
						?>
					</ul>
				</div><!-- .entry-content -->
				<?php if ( ! empty( $btn_txt ) ) : ?>
					<div class="order-now">
						<a href="<?php echo esc_url( $btn_url ); ?>" class="btn btn-default"><?php echo esc_html( $btn_txt ) ?></a>
					</div>
				<?php endif; ?>
			</article>
	<?php

	}

	/**
	 * Outputs the options form on admin
	 *
	 * @param array $instance The widget options
	 */
	public function form( $instance ) {
		// outputs the options form on admin
		$title = isset( $instance['title'] ) ? $instance['title'] : esc_html__( 'Premium', 'emerge-pro' );
		$make_featured = isset( $instance['make_featured'] ) ? (bool)$instance['make_featured'] : false;
		$price = isset( $instance['price'] ) ? $instance['price'] : esc_html__( '$89', 'emerge-pro' );
		$per = isset( $instance['per'] ) ? $instance['per'] : esc_html__( 'Month', 'emerge-pro' );
		$features_num = isset( $instance['features_num'] ) ? $instance['features_num'] : 6;
		$btn_txt = isset( $instance['btn_txt'] ) ? $instance['btn_txt'] : esc_html__( 'Start', 'emerge-pro' );
		$btn_url = isset( $instance['btn_url'] ) ? $instance['btn_url'] : esc_url( 'https://example.com' );
		?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_attr_e( 'Title:', 'emerge-pro' ); ?></label> 
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">

		</p>
		<p>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'make_featured' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'make_featured' ) ); ?>" type="checkbox" <?php checked( $make_featured ); ?> >
			<label for="<?php echo esc_attr( $this->get_field_id( 'make_featured' ) ); ?>"><?php esc_attr_e( 'Make this table featured?', 'emerge-pro' ); ?></label> 
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'price' ) ); ?>"><?php esc_attr_e( 'Price:', 'emerge-pro' ); ?></label> 
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'price' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'price' ) ); ?>" type="text" value="<?php echo esc_attr( $price ); ?>">
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'per' ) ); ?>"><?php esc_attr_e( 'Per:', 'emerge-pro' ); ?></label> 
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'per' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'per' ) ); ?>" type="text" value="<?php echo esc_attr( $per ); ?>">
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'features_num' ) ); ?>"><?php esc_attr_e( 'Number of features:', 'emerge-pro' ); ?></label> 
			<input min="1" max="15" class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'features_num' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'features_num' ) ); ?>" type="number" value="<?php echo esc_attr( $features_num ); ?>">
		</p>

		<?php  
		for ( $i=1; $i <= $features_num; $i++ ) { 
		$features_txt = isset( $instance['features_txt_' . $i] ) ? $instance['features_txt_' . $i ] : __( 'Access To <a href="#">Themes</a>', 'emerge-pro' );

		?>
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'features_txt_' . $i ) ); ?>"><?php esc_attr_e( 'Feature ', 'emerge-pro' ) . $i; ?></label> 
				<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'features_txt_' . $i ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'features_txt_' . $i ) ); ?>" type="text" value="<?php echo esc_attr( $features_txt ); ?>">
			</p>

		<?php 
		}
		?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'btn_txt' ) ); ?>"><?php esc_attr_e( 'Button Text:', 'emerge-pro' ); ?></label> 
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'btn_txt' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'btn_txt' ) ); ?>" type="text" value="<?php echo esc_attr( $btn_txt ); ?>">
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'btn_url' ) ); ?>"><?php esc_attr_e( 'Button URL:', 'emerge-pro' ); ?></label> 
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'btn_url' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'btn_url' ) ); ?>" type="url" value="<?php echo esc_attr( $btn_url ); ?>">
		</p>
		<?php
	}

	/**
	 * Processing widget options on save
	 *
	 * @param array $new_instance The new options
	 * @param array $old_instance The previous options
	 *
	 * @return array
	 */
	public function update( $new_instance, $old_instance ) {
		// processes widget options to be saved
		$instance = array();
		$instance['title'] = ( isset( $new_instance['title'] ) ) ? sanitize_text_field( $new_instance['title'] ) : esc_html__( 'Premium', 'emerge-pro' );
		$instance['make_featured'] = isset( $new_instance['make_featured'] ) ? (bool)$new_instance['make_featured'] : false;
		$instance['price'] = ( isset( $new_instance['price'] ) ) ? sanitize_text_field( $new_instance['price'] ) : __( '<h3>$89</h3><span>Month</span>', 'emerge-pro' );
		$instance['per'] = ( isset( $new_instance['per'] ) ) ? sanitize_text_field( $new_instance['per'] ) : __( 'Month', 'emerge-pro' );
		$instance['btn_txt'] = ( isset( $new_instance['btn_txt'] ) ) ? sanitize_text_field( $new_instance['btn_txt'] ) : esc_html__( 'Start', 'emerge-pro' );
		$instance['btn_url'] = ( isset( $new_instance['btn_url'] ) ) ? esc_url_raw( $new_instance['btn_url'] ) : esc_url( 'https://example.com' );
		$instance['features_num'] = ( isset( $new_instance['features_num'] ) ) ? absint( $new_instance['features_num'] ) : 6;
		$features_num = $instance['features_num'];

		for ( $i=1; $i <= $features_num; $i++ ) { 
			$instance['features_txt_' . $i ] = ( isset( $new_instance['features_txt_' . $i ] ) ) ? emerge_sanitize_html( $new_instance['features_txt_' . $i ] ) : __( 'Access To <a href="#">Themes</a>', 'emerge-pro' );
		}

		return $instance;
	}
}

// Register Emerge_Pricing_Table widget
function register_emerge_pricing_table() {
    register_widget( 'Emerge_Pricing_Table' );
}
add_action( 'widgets_init', 'register_emerge_pricing_table' );